require 'spec_helper'

describe User do
	before do
		@user = User.new(email: "martin@example.com", 
			password: "secret", password_confirmation: "secret")
	end
	
	subject { @user }
	
	it { should respond_to(:email) }
	it { should respond_to(:password) }
	it { should respond_to(:password_confirmation) }
	it { should respond_to(:admin) }
	
	describe "with admin attribute set to 'true'" do
		before { @user.toggle!(:admin) }
		it { should be_admin }
	end

	describe "when email is not present" do
		before { @user.email = " " }
		it { should_not be_valid }
	end
	
	describe "when email format is invalid" do
		invalid_addresses = %w[user@foo,com user_at_foo.org example.user@foo.]
		invalid_addresses.each do |invalid_address|
		before { @user.email = invalid_address }
			it { should_not be_valid }
		end
	end
	
	describe "when email format is valid" do
		valid_addresses = %w[user@foo.com A_USER@f.b.org frst.lst@foo.jp
		a+b@baz.cn]
		valid_addresses.each do |valid_address|
		before { @user.email = valid_address }
			it { should be_valid }
		end
	end
	
	describe "when email address is already taken" do
		before do
			user_with_same_email = @user.dup
			user_with_same_email.email = @user.email.upcase
			user_with_same_email.save
		end
		it { should_not be_valid }
	end
	
	describe "when password is not present" do
		before { @user.password = @user.password_confirmation = " " }
		it { should_not be_valid }
	end
	
	describe "when password doesn't match confirmation" do
		before { @user.password_confirmation = "mismatch" }
		it { should_not be_valid }
	end
	
	describe "with a password that's too short" do
		before { @user.password = @user.password_confirmation = "a" * 5 }
		it { should be_invalid }
	end
	
#	describe "edit" do
#	let(:user) { FactoryGirl.create(:user) }
#		before { visit edit_user_path(user) }

#		describe "edit page" do
#			it { should have_selector('h1', text: "Editing user") }
#		end

#		describe "with invalid information" do
#		let(:error) { '1 error prohibited this user from being saved' }
#			before { click_button "Update" }
#				it { should have_content(error) }
#		end
#	end
end
